CSUMB's CST205 - Simple Multimedia Manipulation
=======================

This project offers students access to a simple RGB Image class, which
is built on the use of the Image module in the PIL package. As PIL is no
longer updated for Python 3, this package relies on **Pillow**.

More classes are in development for manipulation of audio and video.

To install:
  1. Install Python 3.4 or greater (available at https://www.python.org/downloads/)
  2. Install this project's package through the use of pip
    `pip install csumb205-multimedia`
  3. Use the developed modules within Python (currently only an RGB Image class)
    `from simpleImage import rgbImage`

This project's Github IO page, which contains more complete documentation on installation and usage, can be found here.
http://pwalker91.github.io/CSUMB205_Multimedia

The Python Package Index page can be found here.
https://pypi.python.org/pypi/csumb205-multimedia
